@@ -49,7 +49,7 @@ class MySQL:
         """
         Execute a query in the mysql table
         :param string query: query for execution in the table
-        :return None
+        :return :
         """
 
         try:
@@ -64,7 +64,7 @@ class MySQL:
 
         """
         Execute a query in the mysql table
-        :param string query: query for execution in the table
+        :param pd.DataFrame data: dataframe to be appended or replaced
         :param string table_name: name of the the target table
         :param string mode: it can be either replace or append
         :return None
@@ -86,10 +86,7 @@ class MySQL:
         """
         Fetch data from production mysql from local machine via SSH tunnelling (or local port forwarding).
         :param string query: query for execution in the table
-        :param string table_name: name of the the target table
-        :param string db_string: mysql database connection string
-        :param string mode: it can be either replace or append
-        :return None
+        :return :
         """
 
         try:
@@ -118,7 +115,6 @@ class MySQL:
         """
         Fetch data from production mysql as a dataframe.
         :param string query: query for fetching data from table
-        :param string db_string: mysql database connection string
         :return pd.DataFrame data
         """
 
@@ -141,8 +137,7 @@ class MySQL:
         """
         Execute a query in the production mysql table
         :param string query: query for execution in the table
-        :param string db_string: mysql database connection string
-        :return None
+        :return:
         """
 
         try:
@@ -162,12 +157,11 @@ class MySQL:
     def dump_into_prod(data, table_name, mode="append"):
 
         """
-        Execute a query in the production mysql table
-        :param string query: query for execution in the table
+        Push data into production mysql table
+        :param pd.DataFrame data: dataframe to be appended or replaced
         :param string table_name: name of the the target table
-        :param string db_string: mysql database connection string
         :param string mode: it can be either replace or append
-        :return None
+        :return:
         """
 
         try:
