@@ -17,7 +17,7 @@ try:
         )
         response = client.get_secret_value(SecretId=secret_name)
         cred = json.loads(response['SecretString'])
-        print("----------- Connected to AWS via AWS CLI configured credentials -----------------------")
+        print("----------- Connected to Trell AWS S via IAM role or AWS CLI configured credentials -----------------------")
     except Exception as err:
         client = session.client(
             service_name='secretsmanager',
@@ -27,9 +27,9 @@ try:
         )
         response = client.get_secret_value(SecretId=secret_name)
         cred = json.loads(response['SecretString'])
-        print("----------- Connected to AWS via environment credentials -----------------------")
+        print("----------- Connected to Trell AWS via environment credentials -----------------------")
 
     
 except Exception as err:
     print("** --- you are not authorized to use Trell pip package --- **")
-    print("Follow one of the folling steps to use Trell pip package \n 1. Setup AWS CLI \n 2. Place trell.env in the current folder \n 3. manually set up the credentials via \n    from trell_ai_util.utils import Credential \n    Credential.set(ACCESS_KEY='*****', SECRET_KEY='*****') ")
\ No newline at end of file
+    print("Follow one of the folling steps to use Trell pip package \n 1. Attach ds-general-ec2 IAM role to the machine  \n 2. Setup AWS CLI \n 3. manually set up the credentials via \n    from trell_ai_util.utils import Credential \n    Credential.set(ACCESS_KEY='*****', SECRET_KEY='*****') ")
\ No newline at end of file
